@@ -25,11 +25,11 @@ int main(int argc, char *argv[])
 		print_version_and_exit();
 
 	if (argc != 2) {
-		kbd_error(EXIT_FAILURE, 0, _("usage: totextmode\n"));
+		kbd_error(EXIT_FAILURE, 0, _("Usage: %s [option...]\n"), get_progname());
 	}
 
 	if ((fd = getfd(NULL)) < 0)
-		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console"));
+		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console."));
 
 	num = atoi(argv[1]);
 	if (ioctl(fd, KDSETMODE, KD_TEXT)) {
